require 'rspec'
require 'capybara'
require 'capybara/rspec'
require 'capybara/poltergeist'
require 'capybara/cucumber'

Capybara.register_driver :poltergeist do |app|
  Capybara::Poltergeist::Driver.new(app, :phantomjs_options => ['--ignore-ssl-errors=yes', '--ssl-protocol=any', '--load-images=no'])
end
Capybara.register_driver :poltergeist_debug do |app|
  Capybara::Poltergeist::Driver.new(app, :phantomjs_options => ['--ignore-ssl-errors=yes', '--ssl-protocol=any', '--load-images=yes'], :debug => true)
end

Capybara.default_driver = :poltergeist
Capybara.javascript_driver = :poltergeist
Capybara.run_server = false
Capybara.default_wait_time = 10

if ENV['DEBUG'] or ENV['VERBOSE']
  Capybara.default_driver = :poltergeist_debug
  Capybara.javascript_driver = :poltergeist_debug

end

if ENV['SERVER']
  SERVER=ENV['SERVER']
else
  SERVER='localhost'
end

# Screenshot any failed scenario
After do |scenario|
  if scenario.failed?
    Dir::mkdir('screenshots') if not File.directory?('screenshots')
    screenshot = "./screenshots/FAILED_#{scenario.name.gsub(' ','_').gsub(/[^0-9A-Za-z_]/, '')}.png"
    page.driver.render screenshot
    embed screenshot, 'image/png'
  end

end

Before do
  @params = {}
end

# Only login as monitor once, because it's slow
Before ('@asmonitor') do
  if !$asmonitor_cookies
    res = step %Q|I am logged in as "monitor" with password "monitor"|
    $asmonitor_cookies = page.driver.cookies
  else
    $asmonitor_cookies.each do |name, cookie|
      page.driver.set_cookie(name, cookie.value, :domain => cookie.domain, :path => cookie.path)
    end
  end
end

# If we forced-login, let's force-logout to enforce cleanliness
# When using Around, we don't have access to step, so this works
After ('@asmonitor') do |scenario|
  $asmonitor_cookies.each do |name, cookie|
    page.driver.remove_cookie name
  end
end


# Only login as admin once, because it's slow
Before ('@asadmin') do
  if !$asadmin_cookies
    res = step %Q|I am logged in to LogServer as "admin" with password "admin"|
    $asadmin_cookies = page.driver.cookies
  else
    $asadmin_cookies.each do |name, cookie|
      page.driver.set_cookie(name, cookie.value, :domain => cookie.domain, :path => cookie.path)
    end
  end
end

# If we forced-login, let's force-logout to enforce cleanliness
# When using Around, we don't have access to step, so this works
After ('@asadmin') do |scenario|
  $asadmin_cookies.each do |name, cookie|
    page.driver.remove_cookie name
  end
end

# Head straight to nacoma - doing so might involve visiting configure
# FIXME: does it ever?
Before ('@nacoma') do
  step %Q|I enter nacoma|
end

Before ('@configuration') do
  @configuration = NagiosConfiguration.new
end

After ('@configuration') do |scenario|
  #don't remove config dir if the test failed, useful for debugging
  scenario.failed? ? @configuration.reset(false) : @configuration.reset
end
